﻿#include "cmaths.h"

//---------------------------------------------------------------------------------------------
CVec2::CVec2(int px, int py)
{
    x = px;
    y = py;
}

CVec2 CVec2::operator+(const CVec2& rhs)
{
    return CVec2(x + rhs.x, y + rhs.y);
}

CVec2 CVec2::operator-(const CVec2& rhs)
{
    return CVec2(x - rhs.x, y - rhs.y);
}

CVec2 CVec2::operator/(int32_t rhs)
{
    return CVec2(x / rhs, y / rhs);
}

CVec2 CVec2::operator/(float rhs)
{
    return CVec2((float)x / rhs, (float)y / rhs);
}

CVec2 CVec2::operator*(int32_t rhs)
{
    return CVec2(x * rhs, y * rhs);
}

CVec2 CVec2::operator*(float rhs)
{
    return CVec2((float)x * rhs, (float)y * rhs);
}

CVec2 CVec2::operator%(int32_t rhs)
{
    return CVec2(x % rhs, y % rhs);
}

void CVec2::operator+=(const CVec2& rhs)
{
    x += rhs.x;
    y += rhs.y;
}

void CVec2::operator-=(const CVec2& rhs)
{
    x -= rhs.x;
    y -= rhs.y;
}

void CVec2::operator*=(int32_t rhs)
{
    x *= rhs;
    y *= rhs;
}

void CVec2::operator*=(float rhs)
{
    *this = *this * rhs;
}

void CVec2::operator/=(int32_t rhs)
{
    x /= rhs;
    y /= rhs;
}

bool CVec2::operator==(const CVec2& rhs)
{
    return (x == rhs.x) && (y == rhs.y);
}

uint32_t CVec2::squaredLength()
{
    return x * x + y * y;
}

float CVec2::length()
{
    return sqrtf(squaredLength());
}

//---------------------------------------------------------------------------------------------
CRect::CRect()
{
    CRect(CVec2(), CVec2());
}

CRect::CRect(const CVec2& pTL, const CVec2& pBR)
{
    tl = pTL;
    br = pBR;
}
