﻿import QtQuick 2.5
import QtQuick.Controls 1.4
import QtQuick.Dialogs 1.2

ApplicationWindow {
    visible: true
    visibility: "Maximized"
    width: 640
    height: 480
    title: qsTr("Map Editor v0.18")
    property int frame: 1

    FileDialog {
        id: saveDialog
        visible: false
        title: "Choisissez un fichier"
        folder: "file:///maps"
        nameFilters: [ "Fichiers map (*.map)", "Tous les fichiers (*)" ]
        selectExisting: false;
        onAccepted: {
            bridge.save(fileUrl);
            visible=false;
        }

        onRejected: visible=false;
    }

    FileDialog {
        id: loadDialog
        visible: false
        title: "Choisissez un fichier"
        folder: "file:///maps"
        nameFilters: [ "Fichiers map (*.map)", "Tous les fichiers (*)" ]
        selectExisting: true;
        onAccepted: {
            bridge.load(fileUrl);
            visible=false;
        }

        onRejected: visible=false;
    }

    menuBar: MenuBar {
        id: menus
        Menu {
            title: qsTr("Fichier")
            MenuItem {
                text: qsTr("Charger")
                shortcut: "Ctrl+L"
                onTriggered: loadDialog.visible = true;
            }
            MenuItem {
                text: qsTr("Sauver")
                shortcut: "Ctrl+S"
                onTriggered: saveDialog.visible = true;
            }
            MenuItem {
                text: qsTr("Quitter")
                onTriggered: Qt.quit();
            }
        }
        Menu {
            objectName:"editMenu"
            title: qsTr("Edition")
            MenuItem {
                text: qsTr("Copier")
                shortcut: "Ctrl+C"
                onTriggered: bridge.copy();
            }
            MenuItem {
                text: qsTr("Couper")
                shortcut: "Ctrl+X"
                onTriggered: bridge.cut();
            }
            MenuItem {
                text: qsTr("Coller")
                shortcut: "Ctrl+V"
                onTriggered: main.setPasteTool();
            }
            MenuSeparator{
            }
            MenuItem {
                text: qsTr("Défaire")
                shortcut: "Ctrl+Z"
                onTriggered: bridge.undo();
            }
            MenuItem {
                text: qsTr("Refaire")
                shortcut: "Ctrl+Y"
                onTriggered: bridge.redo();
            }
        }
    }

    MainForm {
        id: main
        anchors.fill: parent

        function resetTools()
        {
            drawTool.checked = false;
            selectTool.checked = false;
            pasteTool.checked = false;
        }

        function setPasteTool()
        {
            resetTools();
            pasteTool.checked = true;
            bridge.setTool(2);
        }

        mouseArea1.onMouseXChanged: bridge.setMouse(mouseArea1.mouseX, mouseArea1.mouseY);
        mouseArea1.onMouseYChanged: bridge.setMouse(mouseArea1.mouseX, mouseArea1.mouseY);
        mouseArea1.onExited: bridge.setMouse(-1, -1);
        mouseArea1.onEntered: bridge.setMouse(mouseArea1.mouseX, mouseArea1.mouseY);
        mouseArea1.onPressed: bridge.setMousePress(mouse.button);
        mouseArea1.onReleased: bridge.setMouseRelease(mouse.button);
        tTypeValue.onCurrentIndexChanged: bridge.setSelTileType(tTypeValue.currentIndex);
        wTypeValue.onCurrentIndexChanged:bridge.setSelWallType(wTypeValue.currentIndex);

        drawTool.onClicked: {
            resetTools();
            drawTool.checked = true;
            bridge.setTool(0);
        }

        selectTool.onClicked: {
            resetTools();
            selectTool.checked = true;
            bridge.setTool(1);
        }

        copyTool.onClicked: bridge.copy();
        cutTool.onClicked: bridge.cut();
        pasteTool.onClicked: setPasteTool();

        tabView1.onCurrentIndexChanged: bridge.setTabIndex(tabView1.currentIndex);

        Connections {
            target: bridge
            onNewFrameAvailable: {
                main.image1.source = "image://myimageprovider/" + frame;
                frame++;
            }
        }
    }
}

